PySniff
=======

A simple network sniffer.

------------
Installation
------------

::

    pip install pysniff


-----
Usage
-----

PySniff binds to port 8080 and sniffs the browser network forwarded to that port. It captures the log and displays it in the GUI, logs it out on the console and in addition logs it to the `pysniff.log` log file. 

To start the sniffer run:

::

    pysniff
